Parse/lowering diagnostics. Unsupported constructs are reported here rather than silently dropped (gap-analysis principle: never a silent wrong answer).
Structs
- Diagnostic
- Parse
Error - Fatal parse error (e.g. malformed Turtle).
Parse/lowering diagnostics. Unsupported constructs are reported here rather than silently dropped (gap-analysis principle: never a silent wrong answer).