pub fn parse_turtle(
data: &[u8],
base: Option<&str>,
) -> Result<ParseOutput, ParseError>Expand description
Parse and lower a Turtle shapes graph into the algebra IR.
pub fn parse_turtle(
data: &[u8],
base: Option<&str>,
) -> Result<ParseOutput, ParseError>Parse and lower a Turtle shapes graph into the algebra IR.