Module graph

Module graph 

Loading an RDF graph from Turtle and convenience accessors over it.

Structs

Loaded
A loaded shapes graph plus the prefixes declared in the document.

Enums

RdfFormat

Functions

as_named
The IRI of a named node, or None for blanks/literals.
is_nil
Is this term rdf:nil?
term_to_node
Convert an object term into a subject position node, if it is not a literal.